@@ -68,6 +68,9 @@ class cStock(ConfigBase):
     def get_slippage(self, code):
         return 0.000    
 
+    def get_slippage(self, code):
+        return 0.001
+    
     def init(self, datacenter):
         pass
 
@@ -112,6 +115,7 @@ class cFurture(ConfigBase):
                 
     def get_mutil(self, code):
         if code[-2:] == 'L0': code = code[:-2]
+        code = ''.join([i for i in code if not i.isdigit()])
         c = self.pt_mul.get(code)
         if c is None:
             return 1
@@ -119,6 +123,7 @@ class cFurture(ConfigBase):
 
     def get_open_fee(self, code):
         if code[-2:] == 'L0': code = code[:-2]
+        code = ''.join([i for i in code if not i.isdigit()])
         c = self.com_mar.get(code)
         if c is None:
             return 0,0
@@ -128,6 +133,7 @@ class cFurture(ConfigBase):
 
     def get_close_fee(self, code):
         if code[-2:] == 'L0': code = code[:-2]
+        code = ''.join([i for i in code if not i.isdigit()])
         c = self.com_mar.get(code)
         if c is None:
             return 0,0
@@ -137,6 +143,7 @@ class cFurture(ConfigBase):
 
     def get_close_today_fee(self, code):
         if code[-2:] == 'L0': code = code[:-2]
+        code = ''.join([i for i in code if not i.isdigit()])
         c = self.com_mar.get(code)
         if c is None:
             return 0,0
@@ -146,6 +153,7 @@ class cFurture(ConfigBase):
 
     def get_margin_rate(self, code):
         if code[-2:] == 'L0': code = code[:-2]
+        code = ''.join([i for i in code if not i.isdigit()])
         c = self.com_mar.get(code)
         if c is None:
             return 1
@@ -156,6 +164,7 @@ class cFurture(ConfigBase):
 
     def get_slippage(self, code):
         if code[-2:] == 'L0': code = code[:-2]
+        code = ''.join([i for i in code if not i.isdigit()])
         c1 = self.slippage.get(code)
         if c1 is None:
             return 1
