@@ -1,18 +1,20 @@
 # -*- coding: utf-8 -*-
 from tradeTools import helpers
 from tradeTools import Decorator
-from tmqc.frame import data_center
-from tmqc.frame import stock_func
+from frame import data_center #frame 软连接到trade模块的frame
+from frame import stock_func
 from datetime import datetime
 import pandas as pd
 import numpy as np
 import os
 
+
+
 QUERY_CONF = {} # 查询配置
-QUERY_CONF["PE"] = {}
-QUERY_CONF["PE"]["income"] = {}
-QUERY_CONF["PE"]["income"]["npParentCompanyOwners"] = "归属于母公司股东的净利润"
-    
+QUERY_CONF["balance"] = {}
+QUERY_CONF["balance"]["equitiesParentCompanyOwners"] = "归属于母公司股东权益合计"
+
+
 class Mgr():
     def __init__(self):
         self.oldDc = data_center.use()
@@ -40,17 +42,29 @@ class Mgr():
     
     # 获取上市满1年的股票
     # 过滤st股
-    def getSymbols(self,dateTime = 20210101,isRealTime = False):
-        if not hasattr(self, 'listDf'):
+    def getSymbols(self,dateTime = 20210101,years = -1,isFilterSt = True,isRealTime = False)->list:
+        """_summary_
+
+        Args:
+            dateTime (int, optional): _description_. Defaults to 20210101.
+            years (int, optional): 上市时间约束，默认满一年. Defaults to -1.
+            isFilterSt (bool, optional): 是否过滤st股,注意如果dateTime 大于5月会取最新年报期 Defaults to True.
+            isRealTime (bool, optional): _description_. Defaults to False.
+
+        Returns:
+            list: _description_
+        """
+        if not hasattr(self, 'listDf') or isRealTime:
             self.listDf = helpers.getSymbolsInfo(isRealTime = isRealTime)
             self.listDf = self.listDf.drop_duplicates(subset=["symbol",],keep='first')
             self.listDf = self.listDf.set_index("symbol")
             listDf = self.listDf
         else:
             listDf = self.listDf
-        start = datetime.strptime(str(dateTime), '%Y%m%d') + pd.tseries.offsets.DateOffset(years = -1)
-        symbols= listDf[listDf.listingDate<=start].index.tolist()
-        symbols = list(set(symbols) - set(self.queryST(dateTime =dateTime)))
+        start = datetime.strptime(str(dateTime), '%Y%m%d') + pd.tseries.offsets.DateOffset(years = years)
+        symbols= listDf[listDf.listingDate<=str(start)].index.tolist()
+        if isFilterSt:
+            symbols = list(set(symbols) - set(self.queryST(dateTime =dateTime)))
         return symbols
     
     @Decorator.loadData(path="data")
@@ -62,7 +76,7 @@ class Mgr():
         maxDate = 0
         fileName = kwargs["fileName"]
         if  os.path.exists(fileName):
-            oldDf = pd.read_excel(fileName, sheet_name="数据源", index_col=0,engine="openpyxl")
+            oldDf = pd.read_csv(fileName, index_col=0,)
             maxDate = oldDf["time"].max()
         sql = "SELECT "
         sql += f" code,time,close from `index_day_data` WHERE code = '{indexSymbol}'"
@@ -79,21 +93,25 @@ class Mgr():
             df = oldDf.append(df)
         df[indexSymbol] = df.close / df.close.shift(1) - 1
         return df
-
+    
+    @Decorator.firstLoad
     @Decorator.loadData(path="data")
-    def genSymbolRateData(self, symbol, frequency, isRealTime=False,**kwargs):
+    def genSymbolRateData(self, symbol, isRealTime=False,**kwargs):
         # 生成间隔数据收益率数据
         if not hasattr(self, "oldDc"):
             self.oldDc = data_center.use()
         maxDate = 0
         fileName = kwargs["fileName"]
         if  os.path.exists(fileName): # 读取已有数据文件
-            oldDf = pd.read_excel(fileName, sheet_name="数据源", index_col=0,engine="openpyxl")
+            oldDf = pd.read_csv(fileName, index_col=0,)
             if not oldDf.empty:
                 maxDate = oldDf["time"].max()
             
         sql = "SELECT "
-        sql += f" code,time,close,volume from `tdx_day_data` WHERE code = '{symbol}'"
+        if symbol[-6:].startswith("1"):
+            sql += f" code,time,close,volume from `bond_day_data` WHERE code = '{symbol}'"
+        else:
+            sql += f" code,time,close,volume from `tdx_day_data` WHERE code = '{symbol}'"
         if maxDate:
             sql+=f" and time >={maxDate}" # 多取一条历史数据
         df = pd.read_sql(sql, self.oldDc.database.conn)
@@ -119,11 +137,12 @@ class Mgr():
                     pre_close = stock_func.get_dividend_pre_price(pre_close, dividend[1])  # 前复权
             return (hang.close / pre_close) - 1
 
-        # 如果交易日停牌。则当日和下一个间隔交易日收益率为空
         df["rate"] = df.apply(_getRehabilitationClose, axis=1)
         if maxDate:
             df = df[df.time>maxDate]
             df = oldDf.append(df)
+            df['date'] = pd.to_datetime(df['time'], format='%Y%m%d')
+            df.set_index('date', inplace=True)
         return df
     
         # sql = "SELECT "
@@ -170,11 +189,11 @@ class Mgr():
         df.set_index('date', inplace=True)
         return df
 
-    def getSymbolRateData(self,symbol, frequency=1,isRealTime=False):
+    def getSymbolRateData(self,symbol,isRealTime=False):
         if not hasattr(self, 'symbolRateData'):
                 self.symbolRateData = {}
         if symbol not in self.symbolRateData:
-            symbolRateData = self.genSymbolRateData(symbol=symbol, frequency=1,
+            symbolRateData = self.genSymbolRateData(symbol=symbol,
                                                 isRealTime=isRealTime)
             if symbolRateData.empty:
                 print(f"{symbol}无历史行情数据")
@@ -205,9 +224,9 @@ class Mgr():
     def genReturn(self,beg,end,symbols,weight = []):
         rate = []
         for symbol in symbols:
-            df = self.getSymbolRateData(symbol=symbol,frequency=1)
+            df = self.getSymbolRateData(symbol=symbol,)
             # 计算累计收益率
-            s = df.loc[(beg<df.index) & (df.index<=end)]["mRate"] 
+            s = df.loc[(beg<df.index) & (df.index<=end)]["rate"] 
   
             s.name = symbol
             rate.append(s)
@@ -270,11 +289,15 @@ class Mgr():
         print("近半年最大回撤日期",df["maximumDrawdown"][-120:].idxmax())
         return yearRtn
     
-    def calcRtnByYear(self,df):
+    def calcRtnByYear(self, df,rule="Y",):
         s = {}
-        for i ,_df in df.resample("Y"):
+        for i ,_df in df.resample(rule):
             _s = (1+_df["return"]).cumprod()
-            s[i.year] = _s[-1] - 1 # 每年收益率
+            if rule == "Y":
+                colname = i.year
+            else:
+                colname = f"{i.year}{i.month:0>2d}"
+            s[colname] = _s[-1] - 1 # 每年收益率
         return pd.Series(s)
             
     def calcSharpRatio(self,df):
@@ -291,48 +314,45 @@ class Mgr():
         print("夏普率扣除无风险收益后",r)
         
 
-    @Decorator.loadData()
-    def qryReportData(self, symbol,queryConf = "PE",**kawgrs):
-        sql = "SELECT "
-        tableName = "income"
-        queryConf = QUERY_CONF[queryConf][tableName]
-        for key in queryConf.keys():
-            sql += key + ","
-        sql += f"reportDate FROM {tableName} WHERE symbol ='{symbol}'"
-        df = pd.read_sql(sql, self.oldDc.database.conn)
-        for k, v in queryConf.items():  # 修改列名为【中文+报告期】格式
-            df.rename(columns={k: v}, inplace=True)
-        df = df.set_index("reportDate")
-        df = df.fillna(0)
-        return df
+    @Decorator.loadData(path="data")
+    def qryShiborData(self,**kawgrs):
+        if "year" not in kawgrs:
+        # 汇总
+            total = pd.DataFrame(columns=["曲线名称","日期","3月","6月","1年","3年","5年","7年","10年","30年"])
+            for year in range(2006,2023):
+                _df = self.qryShiborData(year = year)
+                _df['date'] = pd.to_datetime(_df["日期"], format='%Y-%m-%d')
+                _df.set_index('date', inplace=True)
+                total = total.append(_df)
+            return total
+        
+        import akshare as ak
+        year = kawgrs["year"]
+        start_date = f"{year}-01-01"
+        end_date = f"{year}-12-31"
+        bond_china_yield_df = ak.bond_china_yield(start_date=start_date, end_date=end_date)
+        return bond_china_yield_df
+    
+  
     
-    def genTTmPE(self,symbol,dateTime:int):
-        reportDate = helpers.getReportDate(dateTime=dateTime,isUseYear=False) # 真实可获取的年报日期
-        ttmreport = helpers.getTTmReportDates(reportDate) # 上年同季度日期，上年的年报日期，当季报告期
-        reportData = self.qryReportData(symbol = symbol,queryConf="PE")
-        net = reportData.loc[ttmreport[1]]["归属于母公司股东的净利润"]
-        net -= reportData.loc[ttmreport[0]]["归属于母公司股东的净利润"]
-        net += reportData.loc[ttmreport[2]]["归属于母公司股东的净利润"]
-
-        print(net)
-        close,_ = self.oldDc.get_nearest_price(stock_id = symbol, datetime=dateTime)
-        print(close,_)
-        capital= self.oldDc.get_capital(datetime=dateTime, stock_id=symbol,factor_name="total_capital")
-        print(capital)
-        ttmPE = close*capital/net
-        return ttmPE,close*capital,net
 if __name__ == '__main__':
     m = Mgr()
     CON_FREQUENCY = 1
     CON_INDEX_SYMBOL = "SH.000001"
+    # m.qryShiborData()
+    # for year in range(2005,2023):
+    #     print(m.qryShiborData(year = year))
     # idxDf =  m.genIDXData(indexSymbol= CON_INDEX_SYMBOL,isRealTime=True)
     # print(idxDf)
 
     # symbolTScore = m.genSymbolTScore(symbol="SH.600000", frequency =1,windows =30)
-    # r = m.genSymbolRateData(symbol = "SZ.000549", frequency =1, isRealTime=True)
-    # print(r)
+    r = m.genSymbolRateData(symbol = "SH.600000", isRealTime=False)
+    # print(r.index)
+    # r.index =pd.to_datetime(r.index)
+    print(r.index.dtype)
+    print(r.loc[r.index>="20220513"])
     # print(m.qryReportData(symbol = "SZ.000001",queryConf="PE"))
-    # print(m.genTTmPE(symbol="SH.000001",dateTime=20211201))
+    # print(m.genTTmPE(symbol="SH.600519",dateTime=20211201))
     
     # r = m.genReturn(beg =pd.to_datetime(20070521, format='%Y%m%d'),
     #                 end =pd.to_datetime(20070522, format='%Y%m%d'),
