@@ -8,8 +8,8 @@ import re
 import sys
 import requests
 import datetime
-from  tmqc.common import basefunc
-from tmqc.frame import data_center
+from  common import basefunc
+from frame import data_center
 from tradeTools import DataMgr
 from tradeTools import Decorator
 
@@ -146,11 +146,27 @@ class Mgr(DataMgr.Mgr):
 #     #       dtype='object')
 #     df.to_excel("年度净值报告 .xlsx", sheet_name="数据源")
 
+    def getPos(self,dateTime,fullPath):
+        # path = f"F:\workspace_hc\Volatility\股息率_filter_0.00#rate_9_1#rank_rate#groupNum_1检查涨跌停False滑点0.0手续费0.0是否补足开仓数量[False]\stock_transection.log"
+        df = pd.read_csv(fullPath,engine='python',encoding="utf-8", sep='\t')
+        
+        df["成交日期"] = pd.to_datetime(df["成交日期"].str.replace("-",""), format='%Y%m%d')
+        df["成交数量"] = df.apply(lambda x:-x["成交数量"] if x["方向"] == "卖出" else x["成交数量"],axis=1)
+        df = df[df["成交日期"]<=str(dateTime)][["证券代码","成交数量"]]
+        df = df.groupby("证券代码").sum()
+        df = df[df["成交数量"]>0]
+        return df
+    
 if __name__ == '__main__':
     mgr = Mgr()
-    CON_FREQUENCY = 1
-    CON_INDEX_SYMBOL = "SH.000300"
+    path = f"F:\workspace_hc\Volatility\股息率_filter_0.00#rate_9_1#rank_rate#groupNum_1检查涨跌停False滑点0.0手续费0.0是否补足开仓数量[False]\stock_transection.log"
+    dateTime = 20210901
+    df = mgr.getPos(dateTime,fullPath = path)
+    print(df)
+    
+    # CON_FREQUENCY = 1
+    # CON_INDEX_SYMBOL = "SH.000300"
     # idxDf = mgr.genIDXData(symbol=CON_INDEX_SYMBOL, fileExtension=CON_FREQUENCY)
     # df = mgr.qryDayNetValue(logName="20100424INDEX_SYMBOL[SH.000905]USE_PRICEopen是否首次突破才买False是否全平[True]是否平均持仓[False]考虑涨跌停True可持仓数量99999")
     # mgr.concat()
-    print(mgr.qryRateByYear())
+    # print(mgr.qryRateByYear())
